; FILENAME      MAX111.ASM
; DESCRIPTION   MAX111 ADC TEST CHIP
; HARDWARE      JAZZ31 BOARD
; ASSEMBLER     SXA51
; START-DATE    17/07/40
; SOFTWARE ENG  KADIT O.
; COMPANY       SILA RESEARCH CO.,LTD.
;               TEL 712-2850-2 FAX 381-1447

; ********** VARIABLE SET **********

SCLK     EQU    P1.0
CS       EQU    P1.1              ;CHIP SELECT ( START,STOP CONVERSION )
DOUT     EQU    P1.2              ;DATA OUT
DIN      EQU    P1.3              ;DATA IN
BUS      EQU    P1.4              ;BUSY IS LOW WHEN MAX111 IS BUSY

CLEAR    EQU    003CH             ;CLEAR DISPALY BUFFER
SCAND    EQU    0096H             ;SCAN DISPLAY
HTOS     EQU    00E4H             ;HEX TO SEGMENT
HTOD     EQU    00F0H             ;HEX TO DECIMAL

ADCBUF   EQU    20H               ;ADC BUFFER (2 BYTES)
DISBUF   EQU    32H               ;DISPLAY BUFFER (8 BYTES SEGMENT CODE)
HEXBUF   EQU    3AH               ;HEX BUFFER (3 BYTES)

;******* START  PROGRAM ************
         ORG    8100H
         CALL   CLEAR             ;CLEAR DISPLAY
         SETB   CS
         SETB   SCLK
         ACALL  M11CAL1           ;CHANNEL 1 CALIBRATION

; ******* MAIN START HEAR *********
MAIN:   MOV    R2,#10001101B      ;SET COMMAND
        MOV    R3,#00000000B
        ACALL  M11WR              ;WRITE COMMAND
        MOV    R2,#20
        CALL   SCAND              ;SCAN DISPLAY FIRST
        ACALL  M11RD              ;START AND READ ADC
        MOV    ADCBUF+0,R2
        MOV    ADCBUF+1,R3
        ACALL  HTODD
        CALL   HTOS
        MOV    R2,#20
        CALL   SCAND              ;SCAN DISPLAY
        SJMP   MAIN

; ********** M11WR SUB **********
; WRITE CONTROL WORD TO ADC MAX111
; R2,R3  COMMAND
; REG = A,R2,R3,R4,R5,R6

M11WR:   JNB    BUS,$             ;CHECK BUSY
         ACALL  M11DEL
         CLR    SCLK              ;CLK = 0
         ACALL  M11DEL
         CLR    CS                ;STOP CONVERSION
         CALL   M11DEL
         MOV    A,R2              ;8 BIT FIRST
         CALL   M11WRS
         MOV    A,R3              ;8 BIT NEXT
         CALL   M11WRS
         SETB   CS                ;START CONVERSION
         CALL   M11DEL
         RET

M11WRS:  MOV    R5,#8             ;WRITE COMMAND/DATA
M11WRS1: RLC    A
         MOV    DIN,C
         NOP
         SETB   SCLK              ;RISING EDGE CLOCK
         CALL   M11DEL
         CLR    SCLK
         CALL   M11DEL
         DJNZ   R5,M11WRS1
         RET

M11DEL:  MOV    R6,#3             ;DELAY
         DJNZ   R6,$
         RET

; ********** M11RD SUB **********
; READ DATA FROM MAX111 ADC
; OUT = R2,R3 DATA (16 BIT)
; REG = A,R2,R3,R4,R5,R6

M11RD:   JNB    BUS,$             ;CHECK BUSY
         ACALL  M11DEL
         CLR    SCLK
         ACALL  M11DEL
         CLR    CS                ;STOP CONVERSION
         CALL   M11DEL
         CALL   M11RDS
         MOV    R2,A
         CALL   M11RDS
         MOV    R3,A
         SETB   CS                ;START CONVERSION
         CALL   M11DEL
         RET

M11RDS:  MOV    R5,#8             ;READ DATA SUB
         CLR    A
M11RDS1: SETB   SCLK
         CALL   M11DEL
         MOV    C,DOUT
         RLC    A
         CLR    SCLK
         CALL   M11DEL
         DJNZ   R5,M11RDS1
         RET

HTODD:   MOV    A,R2
         ANL    A,#00111111B
         MOV    DPH,A
         MOV    DPL,R3
         CALL   HTOD
         MOV    HEXBUF+0,R1
         MOV    HEXBUF+1,R2
         MOV    HEXBUF+2,R3
         RET

;******* M11CAL1 SUB ************
;MAX111 3 STEP CALIBRATION
;CALIBRATION CHANNEL 1
M11CAL1: MOV    R2,#10001100B     ;STEP 1 CALIBRATION
         MOV    R3,#00001100B
         ACALL  M11WR

         MOV    R2,#10001100B     ;STEP 2 CALIBRATION
         MOV    R3,#00001000B
         ACALL  M11WR

         MOV    R2,#10001100B     ;STEP 3 CALIBRSTION
         MOV    R3,#00000100B
         ACALL  M11WR

         MOV    R2,#10001101B     ;START CONVERSION
         MOV    R3,#00000000B
         ACALL  M11WR
         RET

         END
